#
# TV::Fetch::DGC   - slurps content from DigiGuide-compatible TSV files
# ~~~~~~~~~~~~~~  (c) Andrew Flegg <andrew@bleb.org>, http://www.bleb.org/
# v0.01 (08-Jan-2003) Released under the Artistic Licence.
# 
# File format detailed at:
#    http://www.digiguide.com/dev/dgchan/dgc.shtml
#
# Methods to be implemented:
#         TV::Fetch::Test->new           (<channel id>, <XML data>)
#         TV::Fetch::Test->getInfo       (<prog>)
#         $obj->getProgrammes            (<offset>)

package TV::Fetch::DGC;

use Data::Dumper;
use Date::Calc qw(Today Add_Delta_DHMS Add_Delta_Days);


# -- We're created ------------------------------------------------------
#
sub new {
    my $class    = shift;
    my $channel  = shift || die "No channel name passed to $class";
    my $data     = shift || die "No XML data passed to $class";
    my $self     = bless { channel => $channel, data => $data }, $class;
    my $info     = $data->{channel};

    $info = $info->[0] if ref($info) eq 'ARRAY';
    print "+++ Fetching $info->{dataurl}... " if $self->{data}->{debug};
    my $tsv = TV::Fetch::get($info->{dataurl}) or return '';
    print "done.\n" if $self->{data}->{debug};

    while ($tsv =~ /^(.*)$/mg) {
        my $line = $1;
        $line =~ s/[\r\n]+$//g;
        $line =~ s/^\s+//g;
	$line =~ s/\s+$//g;

        my @field = split(/\t/, $line);
        my %entry = ( date      => $field[0],
                      start     => $field[1],
                      duration  => $field[2],
                      title     => $field[4],
                      type      => $field[5],
                      desc      => $field[6] );
        push @{ $self->{listings} }, \%entry;
    }

    return $self;
}


# -- Get more info on a programme --------------------------------------
#
sub getInfo {
    my $class  = shift;
    my $prog   = shift;

    return 'No further information is available.';
}


# -- Return data on programmes listings --------------------------------
#
sub getProgrammes {
    my $self   = shift;
    my $offset = @_;
    my @data   = ();

    my @target = Add_Delta_Days(Today(), $offset);
    my $date   = "0*$target[2]/0*$target[1]/$target[0]";
    foreach my $p (@{ $self->{listings} }) {
        next unless $p->{date} =~ /$date/;

        unless ($p->{end}) {
            my ($sh, $sm) = $p->{start} =~ /^(\d+?)(\d{2})$/;
            my @start = (@target, $sh, $sm, 00);
            my @end   = Add_Delta_DHMS(@start, 0, 0, $p->{duration}, 0);
            $p->{end} = $end[3]*100 + $end[4];
        }

        push @data, $p;
        print Dumper($p) if $self->{data}->{debug};
    }
    
    return \@data;
}


1;
